pds
pds
Classes
| Name | Description |
|---|---|
| CatalogFilter | useful to make class to keep the base catalog in memory |
CatalogFilter
pds.CatalogFilter(date=None)useful to make class to keep the base catalog in memory
Attributes
| Name | Description |
|---|---|
| uv | return E/F_UV only |